/// <reference types="node" />
import { EventEmitter } from 'events';
import { Transport } from '../utils/transport';
import { ILogger } from '../utils/logger';
export declare type BaseConstructorOptions = {
    transport: Transport;
    logger?: ILogger;
    data?: Buffer;
    metadata?: any;
};
export declare class BaseApi extends EventEmitter {
    protected transport: Transport;
    protected _isReady: Promise<boolean>;
    protected prefix: string;
    logger: ILogger;
    data: Buffer;
    constructor({transport, data, logger, metadata}: BaseConstructorOptions);
    equals(other: BaseApi): boolean;
    request(name: string, args?: any[]): Promise<any>;
    _getArgsByPrefix(...args: any[]): this[];
    /** Retrieves a scoped variable depending on type (using `this.prefix`) */
    getVar(name: string): Promise<string>;
    /** Set a scoped variable */
    setVar(name: string, value: any): Promise<any>;
    /** Delete a scoped variable */
    deleteVar(name: string): Promise<any>;
    /** Retrieves a scoped option depending on type of `this` */
    getOption(name: string): Promise<any> | void;
    /** Set scoped option */
    setOption(name: string, value: any): Promise<any> | void;
    /** `request` is basically the same except you can choose to wait forpromise to be resolved */
    notify(name: string, args: any[]): void;
}
